@@ -1,9 +1,11 @@
 __author__ = 'olga'
 
 from prettyplotlib.utils import remove_chartjunk, maybe_get_ax, maybe_get_linewidth
-from prettyplotlib.colors import almost_black
-
+from prettyplotlib.colors import almost_black, pretty
+from itertools import cycle
+import matplotlib as mpl
 
+@pretty
 def fill_betweenx(*args, **kwargs):
     ax, args, kwargs = maybe_get_ax(*args, **kwargs)
 
@@ -12,10 +14,9 @@ def fill_betweenx(*args, **kwargs):
 
     if 'color' not in kwargs:
         # if no color is specified, cycle over the ones in this axis
-        color_cycle = ax._get_lines.color_cycle
+        color_cycle = cycle(mpl.rcParams['axes.color_cycle'])
         kwargs['color'] = next(color_cycle)
-    if 'edgecolor' not in kwargs:
-        kwargs['edgecolor'] = almost_black
+    kwargs.setdefault('edgecolor', almost_black)
 
     show_ticks = kwargs.pop('show_ticks', False)
 
